@@ -10,16 +10,21 @@ XML = False
 TXT = False
 PICS = False
 PYMOL = False
+STDOUT = False
+RAWSTRING = False # use raw strings for input / output
 OUTPATH = './'
 BASEPATH = './'
 BREAKCOMPOSITE = False  # Break up composite ligands with covalent bonds
 ALTLOC = False  # Consider alternate locations
 PLUGIN_MODE = False  # Special mode for PLIP in Plugins (e.g. PyMOL)
 NOFIX = False  # Turn off fixing of errors in PDB files
+NOFIXFILE = False # Turn off writing to files for fixed PDB structures
 PEPTIDES = []  # Definition which chains should be considered as peptide ligands
 INTRA = None
 KEEPMOD = False
 DNARECEPTOR = False
+OUTPUTFILENAME = "report" # Naming for the TXT and XML report files
+NOPDBCANMAP = False # Skip calculation of mapping canonical atom order: PDB atom order
 
 # Configuration file for Protein-Ligand Interaction Profiler (PLIP)
 # Set thresholds for detection of interactions
