@@ -17,26 +17,25 @@ def filter_contacts(pairings):
     """Filter interactions by two criteria:
     1. No interactions between the same residue (important for intra mode).
     2. No duplicate interactions (A with B and B with A, also important for intra mode)."""
-    if config.INTRA:
-        filtered1_pairings = [p for p in pairings if (p.resnr, p.reschain) != (p.resnr_l, p.reschain_l)]
-        already_considered = []
-        filtered2_pairings = []
-        for contact in filtered1_pairings:
-            try:
-                dist = 'D{}'.format(round(contact.distance,2))
-            except AttributeError:
-                try:
-                    dist = 'D{}'.format(round(contact.distance_ah,2))
-                except AttributeError:
-                    dist = 'D{}'.format(round(contact.distance_aw,2))
-            res1, res2 = ''.join([str(contact.resnr), contact.reschain]), ''.join([str(contact.resnr_l), contact.reschain_l])
-            data = set([res1, res2, dist])
-            if data not in already_considered:
-                filtered2_pairings.append(contact)
-                already_considered.append(data)
-        return filtered2_pairings
-    else:
+    if not config.INTRA:
         return pairings
+    filtered1_pairings = [p for p in pairings if (p.resnr, p.reschain) != (p.resnr_l, p.reschain_l)]
+    already_considered = []
+    filtered2_pairings = []
+    for contact in filtered1_pairings:
+        try:
+            dist = 'D{}'.format(round(contact.distance,2))
+        except AttributeError:
+            try:
+                dist = 'D{}'.format(round(contact.distance_ah,2))
+            except AttributeError:
+                dist = 'D{}'.format(round(contact.distance_aw,2))
+        res1, res2 = ''.join([str(contact.resnr), contact.reschain]), ''.join([str(contact.resnr_l), contact.reschain_l])
+        data = {res1, res2, dist}
+        if data not in already_considered:
+            filtered2_pairings.append(contact)
+            already_considered.append(data)
+    return filtered2_pairings
 
 
 ##################################################
@@ -54,14 +53,15 @@ def hydrophobic_interactions(atom_set_a, atom_set_b):
         if a.orig_idx == b.orig_idx:
             continue
         e = euclidean3d(a.atom.coords, b.atom.coords)
-        if config.MIN_DIST < e < config.HYDROPH_DIST_MAX:
-            restype, resnr, reschain = whichrestype(a.atom), whichresnumber(a.atom), whichchain(a.atom)
-            restype_l, resnr_l, reschain_l = whichrestype(b.orig_atom), whichresnumber(b.orig_atom), whichchain(b.orig_atom)
-            contact = data(bsatom=a.atom, bsatom_orig_idx=a.orig_idx, ligatom=b.atom, ligatom_orig_idx=b.orig_idx,
-                           distance=e, restype=restype, resnr=resnr,
-                           reschain=reschain, restype_l=restype_l,
-                           resnr_l=resnr_l, reschain_l=reschain_l)
-            pairings.append(contact)
+        if not config.MIN_DIST < e < config.HYDROPH_DIST_MAX:
+            continue
+        restype, resnr, reschain = whichrestype(a.atom), whichresnumber(a.atom), whichchain(a.atom)
+        restype_l, resnr_l, reschain_l = whichrestype(b.orig_atom), whichresnumber(b.orig_atom), whichchain(b.orig_atom)
+        contact = data(bsatom=a.atom, bsatom_orig_idx=a.orig_idx, ligatom=b.atom, ligatom_orig_idx=b.orig_idx,
+                       distance=e, restype=restype, resnr=resnr,
+                       reschain=reschain, restype_l=restype_l,
+                       resnr_l=resnr_l, reschain_l=reschain_l)
+        pairings.append(contact)
     return filter_contacts(pairings)
 
 
@@ -75,32 +75,36 @@ def hbonds(acceptors, donor_pairs, protisdon, typ):
                                'restype reschain resnr_l restype_l reschain_l sidechain atype dtype')
     pairings = []
     for acc, don in itertools.product(acceptors, donor_pairs):
-        if typ == 'strong':  # Regular (strong) hydrogen bonds
-            dist_ah = euclidean3d(acc.a.coords, don.h.coords)
-            dist_ad = euclidean3d(acc.a.coords, don.d.coords)
-            if config.MIN_DIST < dist_ad < config.HBOND_DIST_MAX:
-                vec1, vec2 = vector(don.h.coords, don.d.coords), vector(don.h.coords, acc.a.coords)
-                v = vecangle(vec1, vec2)
-                if v > config.HBOND_DON_ANGLE_MIN:
-                    protatom = don.d.OBAtom if protisdon else acc.a.OBAtom
-                    ligatom = don.d.OBAtom if not protisdon else acc.a.OBAtom
-                    is_sidechain_hbond = protatom.GetResidue().GetAtomProperty(protatom, 8)  # Check if sidechain atom
-                    resnr = whichresnumber(don.d) if protisdon else whichresnumber(acc.a)
-                    resnr_l = whichresnumber(acc.a_orig_atom) if protisdon else whichresnumber(don.d_orig_atom)
-                    restype = whichrestype(don.d) if protisdon else whichrestype(acc.a)
-                    restype_l = whichrestype(acc.a_orig_atom) if protisdon else whichrestype(don.d_orig_atom)
-                    reschain = whichchain(don.d) if protisdon else whichchain(acc.a)
-                    rechain_l = whichchain(acc.a_orig_atom) if protisdon else whichchain(don.d_orig_atom)
-                    # Next line prevents H-Bonds within amino acids in intermolecular interactions
-                    if config.INTRA is not None and whichresnumber(don.d) == whichresnumber(acc.a): continue
-                    # Next line prevents backbone-backbone H-Bonds
-                    if config.INTRA is not None and protatom.GetResidue().GetAtomProperty(protatom, 8) and ligatom.GetResidue().GetAtomProperty(ligatom, 8): continue
-                    contact = data(a=acc.a, a_orig_idx=acc.a_orig_idx, d=don.d, d_orig_idx=don.d_orig_idx, h=don.h,
-                                   distance_ah=dist_ah, distance_ad=dist_ad, angle=v, type=typ, protisdon=protisdon,
-                                   resnr=resnr, restype=restype, reschain=reschain, resnr_l=resnr_l,
-                                   restype_l=restype_l, reschain_l=rechain_l, sidechain=is_sidechain_hbond,
-                                   atype=acc.a.type, dtype=don.d.type)
-                    pairings.append(contact)
+        if not typ == 'strong':
+            continue
+        # Regular (strong) hydrogen bonds
+        dist_ah = euclidean3d(acc.a.coords, don.h.coords)
+        dist_ad = euclidean3d(acc.a.coords, don.d.coords)
+        if not config.MIN_DIST < dist_ad < config.HBOND_DIST_MAX:
+            continue
+        vec1, vec2 = vector(don.h.coords, don.d.coords), vector(don.h.coords, acc.a.coords)
+        v = vecangle(vec1, vec2)
+        if not v > config.HBOND_DON_ANGLE_MIN:
+            continue
+        protatom = don.d.OBAtom if protisdon else acc.a.OBAtom
+        ligatom = don.d.OBAtom if not protisdon else acc.a.OBAtom
+        is_sidechain_hbond = protatom.GetResidue().GetAtomProperty(protatom, 8)  # Check if sidechain atom
+        resnr = whichresnumber(don.d) if protisdon else whichresnumber(acc.a)
+        resnr_l = whichresnumber(acc.a_orig_atom) if protisdon else whichresnumber(don.d_orig_atom)
+        restype = whichrestype(don.d) if protisdon else whichrestype(acc.a)
+        restype_l = whichrestype(acc.a_orig_atom) if protisdon else whichrestype(don.d_orig_atom)
+        reschain = whichchain(don.d) if protisdon else whichchain(acc.a)
+        rechain_l = whichchain(acc.a_orig_atom) if protisdon else whichchain(don.d_orig_atom)
+        # Next line prevents H-Bonds within amino acids in intermolecular interactions
+        if config.INTRA is not None and whichresnumber(don.d) == whichresnumber(acc.a): continue
+        # Next line prevents backbone-backbone H-Bonds
+        if config.INTRA is not None and protatom.GetResidue().GetAtomProperty(protatom, 8) and ligatom.GetResidue().GetAtomProperty(ligatom, 8): continue
+        contact = data(a=acc.a, a_orig_idx=acc.a_orig_idx, d=don.d, d_orig_idx=don.d_orig_idx, h=don.h,
+                       distance_ah=dist_ah, distance_ad=dist_ad, angle=v, type=typ, protisdon=protisdon,
+                       resnr=resnr, restype=restype, reschain=reschain, resnr_l=resnr_l,
+                       restype_l=restype_l, reschain_l=rechain_l, sidechain=is_sidechain_hbond,
+                       atype=acc.a.type, dtype=don.d.type)
+        pairings.append(contact)
     return filter_contacts(pairings)
 
 
@@ -125,18 +129,19 @@ def pistacking(rings_bs, rings_lig):
 
         # SELECTION BY DISTANCE, ANGLE AND OFFSET
         passed = False
-        if config.MIN_DIST < d < config.PISTACK_DIST_MAX:
-            if 0 < a < config.PISTACK_ANG_DEV and offset < config.PISTACK_OFFSET_MAX:
-                ptype = 'P'
-                passed = True
-            if 90 - config.PISTACK_ANG_DEV < a < 90 + config.PISTACK_ANG_DEV and offset < config.PISTACK_OFFSET_MAX:
-                ptype = 'T'
-                passed = True
-            if passed:
-                contact = data(proteinring=r, ligandring=l, distance=d, angle=a, offset=offset,
-                               type=ptype, resnr=resnr, restype=restype, reschain=reschain,
-                               resnr_l=resnr_l, restype_l=restype_l, reschain_l=reschain_l)
-                pairings.append(contact)
+        if not config.MIN_DIST < d < config.PISTACK_DIST_MAX:
+            continue
+        if 0 < a < config.PISTACK_ANG_DEV and offset < config.PISTACK_OFFSET_MAX:
+            ptype = 'P'
+            passed = True
+        if 90 - config.PISTACK_ANG_DEV < a < 90 + config.PISTACK_ANG_DEV and offset < config.PISTACK_OFFSET_MAX:
+            ptype = 'T'
+            passed = True
+        if passed:
+            contact = data(proteinring=r, ligandring=l, distance=d, angle=a, offset=offset,
+                           type=ptype, resnr=resnr, restype=restype, reschain=reschain,
+                           resnr_l=resnr_l, restype_l=restype_l, reschain_l=reschain_l)
+            pairings.append(contact)
     return filter_contacts(pairings)
 
 
@@ -146,46 +151,48 @@ def pication(rings, pos_charged, protcharged):
     """
     data = namedtuple('pication', 'ring charge distance offset type restype resnr reschain restype_l resnr_l reschain_l protcharged')
     pairings = []
-    if not len(rings) == 0 and not len(pos_charged) == 0:
-        for ring in rings:
-            c = ring.center
-            for p in pos_charged:
-                d = euclidean3d(c, p.center)
-                # Project the center of charge into the ring and measure distance to ring center
-                proj = projection(ring.normal, ring.center, p.center)
-                offset = euclidean3d(proj, ring.center)
-                if config.MIN_DIST < d < config.PICATION_DIST_MAX and offset < config.PISTACK_OFFSET_MAX:
-                    if type(p).__name__ == 'lcharge' and p.fgroup == 'tertamine':
-                        # Special case here if the ligand has a tertiary amine, check an additional angle
-                        # Otherwise, we might have have a pi-cation interaction 'through' the ligand
-                        n_atoms = [a_neighbor for a_neighbor in OBAtomAtomIter(p.atoms[0].OBAtom)]
-                        n_atoms_coords = [(a.x(), a.y(), a.z()) for a in n_atoms]
-                        amine_normal = np.cross(vector(n_atoms_coords[0], n_atoms_coords[1]),
-                                                vector(n_atoms_coords[2], n_atoms_coords[0]))
-                        b = vecangle(ring.normal, amine_normal)
-                        # Smallest of two angles, depending on direction of normal
-                        a = min(b, 180 - b if not 180 - b < 0 else b)
-                        if not a > 30.0:
-                            resnr, restype = whichresnumber(ring.atoms[0]), whichrestype(ring.atoms[0])
-                            reschain = whichchain(ring.atoms[0])
-                            resnr_l, restype_l = whichresnumber(p.orig_atoms[0]), whichrestype(p.orig_atoms[0])
-                            reschain_l = whichchain(p.orig_atoms[0])
-                            contact = data(ring=ring, charge=p, distance=d, offset=offset, type='regular',
-                                           restype=restype, resnr=resnr, reschain=reschain,
-                                           restype_l=restype_l, resnr_l=resnr_l, reschain_l=reschain_l,
-                                           protcharged=protcharged)
-                            pairings.append(contact)
-                        break
-                    resnr = whichresnumber(p.atoms[0]) if protcharged else whichresnumber(ring.atoms[0])
-                    resnr_l = whichresnumber(ring.orig_atoms[0]) if protcharged else whichresnumber(p.orig_atoms[0])
-                    restype = whichrestype(p.atoms[0]) if protcharged else whichrestype(ring.atoms[0])
-                    restype_l = whichrestype(ring.orig_atoms[0]) if protcharged else whichrestype(p.orig_atoms[0])
-                    reschain = whichchain(p.atoms[0]) if protcharged else whichchain(ring.atoms[0])
-                    reschain_l = whichchain(ring.orig_atoms[0]) if protcharged else whichchain(p.orig_atoms[0])
-                    contact = data(ring=ring, charge=p, distance=d, offset=offset, type='regular', restype=restype,
-                                   resnr=resnr, reschain=reschain, restype_l=restype_l, resnr_l=resnr_l,
-                                   reschain_l=reschain_l, protcharged=protcharged)
+    if len(rings) == 0 or len(pos_charged) == 0:
+        return pairings
+    for ring in rings:
+        c = ring.center
+        for p in pos_charged:
+            d = euclidean3d(c, p.center)
+            # Project the center of charge into the ring and measure distance to ring center
+            proj = projection(ring.normal, ring.center, p.center)
+            offset = euclidean3d(proj, ring.center)
+            if not config.MIN_DIST < d < config.PICATION_DIST_MAX or not offset < config.PISTACK_OFFSET_MAX:
+                continue
+            if type(p).__name__ == 'lcharge' and p.fgroup == 'tertamine':
+                # Special case here if the ligand has a tertiary amine, check an additional angle
+                # Otherwise, we might have have a pi-cation interaction 'through' the ligand
+                n_atoms = [a_neighbor for a_neighbor in OBAtomAtomIter(p.atoms[0].OBAtom)]
+                n_atoms_coords = [(a.x(), a.y(), a.z()) for a in n_atoms]
+                amine_normal = np.cross(vector(n_atoms_coords[0], n_atoms_coords[1]),
+                                        vector(n_atoms_coords[2], n_atoms_coords[0]))
+                b = vecangle(ring.normal, amine_normal)
+                # Smallest of two angles, depending on direction of normal
+                a = min(b, 180 - b if not 180 - b < 0 else b)
+                if not a > 30.0:
+                    resnr, restype = whichresnumber(ring.atoms[0]), whichrestype(ring.atoms[0])
+                    reschain = whichchain(ring.atoms[0])
+                    resnr_l, restype_l = whichresnumber(p.orig_atoms[0]), whichrestype(p.orig_atoms[0])
+                    reschain_l = whichchain(p.orig_atoms[0])
+                    contact = data(ring=ring, charge=p, distance=d, offset=offset, type='regular',
+                                   restype=restype, resnr=resnr, reschain=reschain,
+                                   restype_l=restype_l, resnr_l=resnr_l, reschain_l=reschain_l,
+                                   protcharged=protcharged)
                     pairings.append(contact)
+                break
+            resnr = whichresnumber(p.atoms[0]) if protcharged else whichresnumber(ring.atoms[0])
+            resnr_l = whichresnumber(ring.orig_atoms[0]) if protcharged else whichresnumber(p.orig_atoms[0])
+            restype = whichrestype(p.atoms[0]) if protcharged else whichrestype(ring.atoms[0])
+            restype_l = whichrestype(ring.orig_atoms[0]) if protcharged else whichrestype(p.orig_atoms[0])
+            reschain = whichchain(p.atoms[0]) if protcharged else whichchain(ring.atoms[0])
+            reschain_l = whichchain(ring.orig_atoms[0]) if protcharged else whichchain(p.orig_atoms[0])
+            contact = data(ring=ring, charge=p, distance=d, offset=offset, type='regular', restype=restype,
+                           resnr=resnr, reschain=reschain, restype_l=restype_l, resnr_l=resnr_l,
+                           reschain_l=reschain_l, protcharged=protcharged)
+            pairings.append(contact)
     return filter_contacts(pairings)
 
 
@@ -194,17 +201,18 @@ def saltbridge(poscenter, negcenter, protispos):
     data = namedtuple('saltbridge', 'positive negative distance protispos resnr restype reschain resnr_l restype_l reschain_l')
     pairings = []
     for pc, nc in itertools.product(poscenter, negcenter):
-        if config.MIN_DIST < euclidean3d(pc.center, nc.center) < config.SALTBRIDGE_DIST_MAX:
-            resnr = pc.resnr if protispos else nc.resnr
-            resnr_l = whichresnumber(nc.orig_atoms[0]) if protispos else whichresnumber(pc.orig_atoms[0])
-            restype = pc.restype if protispos else nc.restype
-            restype_l = whichrestype(nc.orig_atoms[0]) if protispos else whichrestype(pc.orig_atoms[0])
-            reschain = pc.reschain if protispos else nc.reschain
-            reschain_l = whichchain(nc.orig_atoms[0]) if protispos else whichchain(pc.orig_atoms[0])
-            contact = data(positive=pc, negative=nc, distance=euclidean3d(pc.center, nc.center), protispos=protispos,
-                           resnr=resnr, restype=restype, reschain=reschain, resnr_l=resnr_l, restype_l=restype_l,
-                           reschain_l=reschain_l)
-            pairings.append(contact)
+        if not config.MIN_DIST < euclidean3d(pc.center, nc.center) < config.SALTBRIDGE_DIST_MAX:
+            continue
+        resnr = pc.resnr if protispos else nc.resnr
+        resnr_l = whichresnumber(nc.orig_atoms[0]) if protispos else whichresnumber(pc.orig_atoms[0])
+        restype = pc.restype if protispos else nc.restype
+        restype_l = whichrestype(nc.orig_atoms[0]) if protispos else whichrestype(pc.orig_atoms[0])
+        reschain = pc.reschain if protispos else nc.reschain
+        reschain_l = whichchain(nc.orig_atoms[0]) if protispos else whichchain(pc.orig_atoms[0])
+        contact = data(positive=pc, negative=nc, distance=euclidean3d(pc.center, nc.center), protispos=protispos,
+                       resnr=resnr, restype=restype, reschain=reschain, resnr_l=resnr_l, restype_l=restype_l,
+                       reschain_l=reschain_l)
+        pairings.append(contact)
     return filter_contacts(pairings)
 
 
@@ -215,24 +223,27 @@ def halogen(acceptor, donor):
     pairings = []
     for acc, don in itertools.product(acceptor, donor):
         dist = euclidean3d(acc.o.coords, don.x.coords)
-        if config.MIN_DIST < dist < config.HALOGEN_DIST_MAX:
-            vec1, vec2 = vector(acc.o.coords, acc.y.coords), vector(acc.o.coords, don.x.coords)
-            vec3, vec4 = vector(don.x.coords, acc.o.coords), vector(don.x.coords, don.c.coords)
-            acc_angle, don_angle = vecangle(vec1, vec2), vecangle(vec3, vec4)
-            is_sidechain_hal = acc.o.OBAtom.GetResidue().GetAtomProperty(acc.o.OBAtom, 8)  # Check if sidechain atom
-            if config.HALOGEN_ACC_ANGLE - config.HALOGEN_ANGLE_DEV < acc_angle \
-                    < config.HALOGEN_ACC_ANGLE + config.HALOGEN_ANGLE_DEV:
-                if config.HALOGEN_DON_ANGLE - config.HALOGEN_ANGLE_DEV < don_angle \
-                        < config.HALOGEN_DON_ANGLE + config.HALOGEN_ANGLE_DEV:
-                    restype, reschain, resnr = whichrestype(acc.o), whichchain(acc.o), whichresnumber(acc.o)
-                    restype_l, reschain_l, resnr_l = whichrestype(don.orig_x), whichchain(don.orig_x), whichresnumber(don.orig_x)
-                    contact = data(acc=acc, acc_orig_idx=acc.o_orig_idx, don=don, don_orig_idx=don.x_orig_idx,
-                                   distance=dist, don_angle=don_angle, acc_angle=acc_angle,
-                                   restype=restype, resnr=resnr,
-                                   reschain=reschain, restype_l=restype_l,
-                                   reschain_l=reschain_l, resnr_l=resnr_l, donortype=don.x.OBAtom.GetType(), acctype=acc.o.type,
-                                   sidechain=is_sidechain_hal)
-                    pairings.append(contact)
+        if not config.MIN_DIST < dist < config.HALOGEN_DIST_MAX:
+            continue
+        vec1, vec2 = vector(acc.o.coords, acc.y.coords), vector(acc.o.coords, don.x.coords)
+        vec3, vec4 = vector(don.x.coords, acc.o.coords), vector(don.x.coords, don.c.coords)
+        acc_angle, don_angle = vecangle(vec1, vec2), vecangle(vec3, vec4)
+        is_sidechain_hal = acc.o.OBAtom.GetResidue().GetAtomProperty(acc.o.OBAtom, 8)  # Check if sidechain atom
+        if not config.HALOGEN_ACC_ANGLE - config.HALOGEN_ANGLE_DEV < acc_angle \
+                < config.HALOGEN_ACC_ANGLE + config.HALOGEN_ANGLE_DEV:
+            continue
+        if not config.HALOGEN_DON_ANGLE - config.HALOGEN_ANGLE_DEV < don_angle \
+                < config.HALOGEN_DON_ANGLE + config.HALOGEN_ANGLE_DEV:
+            continue
+        restype, reschain, resnr = whichrestype(acc.o), whichchain(acc.o), whichresnumber(acc.o)
+        restype_l, reschain_l, resnr_l = whichrestype(don.orig_x), whichchain(don.orig_x), whichresnumber(don.orig_x)
+        contact = data(acc=acc, acc_orig_idx=acc.o_orig_idx, don=don, don_orig_idx=don.x_orig_idx,
+                       distance=dist, don_angle=don_angle, acc_angle=acc_angle,
+                       restype=restype, resnr=resnr,
+                       reschain=reschain, restype_l=restype_l,
+                       reschain_l=reschain_l, resnr_l=resnr_l, donortype=don.x.OBAtom.GetType(), acctype=acc.o.type,
+                       sidechain=is_sidechain_hal)
+        pairings.append(contact)
     return filter_contacts(pairings)
 
 
@@ -269,32 +280,38 @@ def water_bridges(bs_hba, lig_hba, bs_hbd, lig_hbd, water):
     for l, p in itertools.product(lig_aw, prot_hw):
         acc, wl, distance_aw = l
         don, wd, distance_dw, d_angle = p
-        if wl.oxy == wd.oxy:  # Same water molecule and angle within omega
-            w_angle = vecangle(vector(acc.a.coords, wl.oxy.coords), vector(wl.oxy.coords, don.h.coords))
-            if config.WATER_BRIDGE_OMEGA_MIN < w_angle < config.WATER_BRIDGE_OMEGA_MAX:
-                resnr, reschain, restype = whichresnumber(don.d), whichchain(don.d), whichrestype(don.d)
-                resnr_l, reschain_l, restype_l = whichresnumber(acc.a_orig_atom), whichchain(acc.a_orig_atom), whichrestype(acc.a_orig_atom)
-                contact = data(a=acc.a, a_orig_idx=acc.a_orig_idx, atype=acc.a.type, d=don.d, d_orig_idx=don.d_orig_idx,
-                               dtype=don.d.type, h=don.h, water=wl.oxy, water_orig_idx=wl.oxy_orig_idx,
-                               distance_aw=distance_aw, distance_dw=distance_dw, d_angle=d_angle, w_angle=w_angle,
-                               type='first_deg', resnr=resnr, restype=restype,
-                               reschain=reschain, restype_l=restype_l, resnr_l=resnr_l, reschain_l=reschain_l, protisdon=True)
-                pairings.append(contact)
+        if not wl.oxy == wd.oxy:
+            continue
+        # Same water molecule and angle within omega
+        w_angle = vecangle(vector(acc.a.coords, wl.oxy.coords), vector(wl.oxy.coords, don.h.coords))
+        if not config.WATER_BRIDGE_OMEGA_MIN < w_angle < config.WATER_BRIDGE_OMEGA_MAX:
+            continue
+        resnr, reschain, restype = whichresnumber(don.d), whichchain(don.d), whichrestype(don.d)
+        resnr_l, reschain_l, restype_l = whichresnumber(acc.a_orig_atom), whichchain(acc.a_orig_atom), whichrestype(acc.a_orig_atom)
+        contact = data(a=acc.a, a_orig_idx=acc.a_orig_idx, atype=acc.a.type, d=don.d, d_orig_idx=don.d_orig_idx,
+                       dtype=don.d.type, h=don.h, water=wl.oxy, water_orig_idx=wl.oxy_orig_idx,
+                       distance_aw=distance_aw, distance_dw=distance_dw, d_angle=d_angle, w_angle=w_angle,
+                       type='first_deg', resnr=resnr, restype=restype,
+                       reschain=reschain, restype_l=restype_l, resnr_l=resnr_l, reschain_l=reschain_l, protisdon=True)
+        pairings.append(contact)
     for p, l in itertools.product(prot_aw, lig_dw):
         acc, wl, distance_aw = p
         don, wd, distance_dw, d_angle = l
-        if wl.oxy == wd.oxy:  # Same water molecule and angle within omega
-            w_angle = vecangle(vector(acc.a.coords, wl.oxy.coords), vector(wl.oxy.coords, don.h.coords))
-            if config.WATER_BRIDGE_OMEGA_MIN < w_angle < config.WATER_BRIDGE_OMEGA_MAX:
-                resnr, reschain, restype = whichresnumber(acc.a), whichchain(acc.a), whichrestype(acc.a)
-                resnr_l, reschain_l, restype_l = whichresnumber(don.d_orig_atom), whichchain(don.d_orig_atom), whichrestype(don.d_orig_atom)
-                contact = data(a=acc.a, a_orig_idx=acc.a_orig_idx, atype=acc.a.type, d=don.d, d_orig_idx=don.d_orig_idx,
-                               dtype=don.d.type, h=don.h, water=wl.oxy, water_orig_idx=wl.oxy_orig_idx,
-                               distance_aw=distance_aw, distance_dw=distance_dw,
-                               d_angle=d_angle, w_angle=w_angle, type='first_deg', resnr=resnr,
-                               restype=restype, reschain=reschain,
-                               restype_l=restype_l, reschain_l=reschain_l, resnr_l=resnr_l, protisdon=False)
-                pairings.append(contact)
+        if not wl.oxy == wd.oxy:
+            continue
+        # Same water molecule and angle within omega
+        w_angle = vecangle(vector(acc.a.coords, wl.oxy.coords), vector(wl.oxy.coords, don.h.coords))
+        if not config.WATER_BRIDGE_OMEGA_MIN < w_angle < config.WATER_BRIDGE_OMEGA_MAX:
+            continue
+        resnr, reschain, restype = whichresnumber(acc.a), whichchain(acc.a), whichrestype(acc.a)
+        resnr_l, reschain_l, restype_l = whichresnumber(don.d_orig_atom), whichchain(don.d_orig_atom), whichrestype(don.d_orig_atom)
+        contact = data(a=acc.a, a_orig_idx=acc.a_orig_idx, atype=acc.a.type, d=don.d, d_orig_idx=don.d_orig_idx,
+                       dtype=don.d.type, h=don.h, water=wl.oxy, water_orig_idx=wl.oxy_orig_idx,
+                       distance_aw=distance_aw, distance_dw=distance_dw,
+                       d_angle=d_angle, w_angle=w_angle, type='first_deg', resnr=resnr,
+                       restype=restype, reschain=reschain,
+                       restype_l=restype_l, reschain_l=reschain_l, resnr_l=resnr_l, protisdon=False)
+        pairings.append(contact)
     return filter_contacts(pairings)
 
 
@@ -310,13 +327,14 @@ def metal_complexation(metals, metal_binding_lig, metal_binding_bs):
     metal_to_orig_atom = {}
     for metal, target in itertools.product(metals, metal_binding_lig + metal_binding_bs):
         distance = euclidean3d(metal.m.coords, target.atom.coords)
-        if distance < config.METAL_DIST_MAX:
-            if metal.m not in pairings_dict:
-                pairings_dict[metal.m] = [(target, distance), ]
-                metal_to_id[metal.m] = metal.m_orig_idx
-                metal_to_orig_atom[metal.m] = metal.orig_m
-            else:
-                pairings_dict[metal.m].append((target, distance))
+        if not distance < config.METAL_DIST_MAX:
+            continue
+        if metal.m not in pairings_dict:
+            pairings_dict[metal.m] = [(target, distance), ]
+            metal_to_id[metal.m] = metal.m_orig_idx
+            metal_to_orig_atom[metal.m] = metal.orig_m
+        else:
+            pairings_dict[metal.m].append((target, distance))
     for cnum, metal in enumerate(pairings_dict):
         rms = 0.0
         excluded = []
