@@ -1,20 +1,8 @@
 """
 Protein-Ligand Interaction Profiler - Analyze and visualize protein-ligand interactions in PDB files.
 pymolplip.py - Visualization class for PyMOL.
-Copyright 2014-2015 Sebastian Salentin
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
 """
+
 from pymol import cmd
 from time import sleep
 import sys
@@ -81,7 +69,7 @@ class PyMOLVisualizer:
         idlist = list(set(idlist))  # Remove duplicates
         if not selection_exists:
             cmd.select(selname, 'None')  # Empty selection first
-        idchunks = [idlist[i:i+chunksize] for i in xrange(0, len(idlist), chunksize)]
+        idchunks = [idlist[i:i+chunksize] for i in range(0, len(idlist), chunksize)]
         for idchunk in idchunks:
             cmd.select(selname, '%s or (id %s)' % (selname, '+'.join(map(str, idchunk))))
         if restrict is not None:
@@ -98,6 +86,7 @@ class PyMOLVisualizer:
         if not len(hydroph.bs_ids) == 0:
             self.select_by_ids('Hydrophobic-P', hydroph.bs_ids, restrict=self.protname)
             self.select_by_ids('Hydrophobic-L', hydroph.lig_ids, restrict=self.ligname)
+
             for i in hydroph.pairs_ids:
                 cmd.select('tmp_bs', 'id %i & %s' % (i[0], self.protname))
                 cmd.select('tmp_lig', 'id %i & %s' % (i[1], self.ligname))
@@ -291,7 +280,11 @@ class PyMOLVisualizer:
 
         selections = cmd.get_names("selections")
         for selection in selections:
-            if cmd.count_atoms(selection) == 0:
+            try:
+                empty = len(cmd.get_model(selection).atom) == 0
+            except:
+                empty = True
+            if empty:
                 cmd.delete(selection)
         cmd.deselect()
         cmd.delete('tmp*')
@@ -401,6 +394,7 @@ class PyMOLVisualizer:
         cmd.set('direct', 0)
         cmd.set('ray_shadow', 0)  # Gives the molecules a flat, modern look
         cmd.set('ambient_occlusion_mode', 1)
+        cmd.set('ray_opaque_background', 0) # Transparent background
 
     def adapt_for_peptides(self):
         """Adapt visualization for peptide ligands and interchain contacts"""
@@ -412,6 +406,10 @@ class PyMOLVisualizer:
         cmd.remove('%sCartoon and chain %s' % (self.protname, self.plcomplex.chain))
         cmd.set('cartoon_side_chain_helper', 0)
 
+    def adapt_for_intra(self):
+        """Adapt visualization for intra-protein interactions"""
+
+
 
 
 
@@ -456,3 +454,6 @@ class PyMOLVisualizer:
 
         if self.ligandtype in ['PEPTIDE', 'INTRA']:
             self.adapt_for_peptides()
+
+        if self.ligandtype == 'INTRA':
+            self.adapt_for_intra()
