@@ -8,7 +8,7 @@ from __future__ import print_function
 from __future__ import absolute_import
 
 # PLIP Modules
-import plip.modules.config as config
+from . import config
 
 # Python standard library
 import re
@@ -27,8 +27,6 @@ import pybel
 from pybel import *
 from openbabel import *
 import numpy as np
-from pymol import cmd
-from pymol import finish_launching
 import itertools
 
 # Settings
@@ -92,7 +90,7 @@ def vector(p1, p2):
     :param p2: coordinates of point p2
     :returns : numpy array with vector coordinates
     """
-    return None if len(p1) != len(p2) else np.array([p2[i] - p1[i] for i in xrange(len(p1))])
+    return None if len(p1) != len(p2) else np.array([p2[i] - p1[i] for i in range(len(p1))])
 
 
 def vecangle(v1, v2, deg=True):
@@ -123,7 +121,7 @@ def centroid(coo):
     :param coo: Array of coordinate arrays
     :returns : centroid coordinates as list
     """
-    return map(np.mean, (([c[0] for c in coo]), ([c[1] for c in coo]), ([c[2] for c in coo])))
+    return list(map(np.mean, (([c[0] for c in coo]), ([c[1] for c in coo]), ([c[2] for c in coo]))))
 
 
 def projection(pnormal1, ppoint, tpoint):
@@ -221,9 +219,10 @@ def cmd_exists(c):
 
 def initialize_pymol(options):
     """Initializes PyMOL"""
+    import pymol
     # Pass standard arguments of function to prevent PyMOL from printing out PDB headers (workaround)
-    finish_launching(args=['pymol', options, '-K'])
-    cmd.reinitialize()
+    pymol.finish_launching(args=['pymol', options, '-K'])
+    pymol.cmd.reinitialize()
 
 
 def start_pymol(quiet=False, options='-p', run=False):
@@ -234,7 +233,7 @@ def start_pymol(quiet=False, options='-p', run=False):
     if run:
         initialize_pymol(options)
     if quiet:
-        cmd.feedback('disable', 'all', 'everything')
+        pymol.cmd.feedback('disable', 'all', 'everything')
 
 def nucleotide_linkage(residues):
     """Support for DNA/RNA ligands by finding missing covalent linkages to stitch DNA/RNA together."""
@@ -334,15 +333,16 @@ def get_isomorphisms(reference, lig):
     return isomorphs
 
 
-def canonicalize(lig):
+def canonicalize(lig, preserve_bond_order=False):
     """Get the canonical atom order for the ligand."""
     atomorder = None
     # Get canonical atom order
 
     lig = pybel.ob.OBMol(lig.OBMol)
-    for bond in pybel.ob.OBMolBondIter(lig):
-        if bond.GetBondOrder() != 1:
-            bond.SetBondOrder(1)
+    if not preserve_bond_order:
+        for bond in pybel.ob.OBMolBondIter(lig):
+            if bond.GetBondOrder() != 1:
+                bond.SetBondOrder(1)
     lig.DeleteData(pybel.ob.StereoData)
     lig = pybel.Molecule(lig)
     testcan = lig.write(format='can')
@@ -398,33 +398,40 @@ def read(fil):
         zf = zipfile.ZipFile(fil, 'r')
         return zf.open(zf.infolist()[0].filename)
     else:
-        try:
-            codecs.open(fil, 'r', 'utf-8').read()
-            return codecs.open(fil, 'r', 'utf-8')
-        except UnicodeDecodeError:
-            return open(fil, 'r')
+        return open(fil, 'r')
+        #try:
+        #    codecs.open(fil, 'r', 'utf-8').read()
+        #    return codecs.open(fil, 'r', 'utf-8')
+        #except UnicodeDecodeError:
+        #    return open(fil, 'r')
 
 
 def readmol(path, as_string=False):
     """Reads the given molecule file and returns the corresponding Pybel molecule as well as the input file type.
     In contrast to the standard Pybel implementation, the file is closed properly."""
-    supported_formats = ['pdb', 'mmcif']
-    obc = pybel.ob.OBConversion()
+    supported_formats = ['pdb']
+    # Fix for Windows-generated files: Remove carriage return characters
+    if "\r" in path and as_string:
+        path = path.replace('\r', '')
 
     for sformat in supported_formats:
+        obc = pybel.ob.OBConversion()
         obc.SetInFormat(sformat)
         write_message("Detected {} as format. Now trying to read file with OpenBabel...\n".format(sformat), mtype='debug')
         mol = pybel.ob.OBMol()
 
         # Read molecules with single bond information
         if as_string:
-            read_file = pybel.readstring(format=sformat, filename=path, opt={"s": None})
+            try:
+                mymol = pybel.readstring(sformat, path)
+            except IOError:
+                sysexit(4, 'No valid file format provided.')
         else:
             read_file = pybel.readfile(format=sformat, filename=path, opt={"s": None})
-        try:
-            mymol = read_file.next()
-        except StopIteration:
-            sysexit(4, 'File contains no valid molecules.\n')
+            try:
+                mymol = next(read_file)
+            except StopIteration:
+                sysexit(4, 'File contains no valid molecules.\n')
 
         write_message("Molecule successfully read.\n", mtype='debug')
 
@@ -487,7 +494,4 @@ def message(msg, indent=False, mtype='standard', caption=False):
         msg = colorlog('Info:  ' + msg, 'green')
     if indent:
         msg = '  ' + msg
-    if mtype in ['error', 'warning']:
-        sys.stderr.write(msg)
-    else:
-        sys.stdout.write(msg)
+    sys.stderr.write(msg)
